# OrganizationV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** |  | 
**address** | [**OrganizationAddressV30Rc1**](OrganizationAddressV30Rc1.md) |  | 
**disambiguated_organization** | [**DisambiguatedOrganizationV30Rc1**](DisambiguatedOrganizationV30Rc1.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

